from flask import jsonify, abort, request
from flask_jwt_extended import jwt_required, get_jwt_identity

from app.doc.product_swag import create_product_swagger

from flasgger import swag_from

from app.api import bp_product

from app.services.product import product_create_service


@bp_product.route("/create", methods=["POST"])
@swag_from(create_product_swagger)
@jwt_required()
def create_product_listing():
    user_id = get_jwt_identity()
    name = request.json.get("name")
    price = request.json.get("price")

    if name is None or price is None:
        return abort(400)

    float_price = float(price)

    if not isinstance(float_price, float):
        return abort(400)

    result, status_code = product_create_service.create_product(
        user_id, name, float_price
    )

    return jsonify(result), status_code
